powerSetMat <-
function(n) {
  combinations(rep.int(2, n))
}
